## Dataset Attribution
This inventory was created by Sandra L. Bem. The use of the lexicons from the
paper is believed to be *fair use* for the reasons stated in the `FAIR_USE.md`
file.

- Original Source: _The measurment of psychological androgyny_
[[Bem 1974](https://www.bibb.de/dokumente/pdf/AB26_WBT3_Vertiefung_Bem-1974.pdf)].

### Definition
Because the BSRI was founded on a conception of the sex-typed person as someone
who has internalized society's sex-typed standards of desirable behavior for men
and women, these personality characteristics were selected as masculine or
feminine on the basis of sex-typed social desirability and not on the basis of
differential endorsement by males and females as most other inventories have
done. That is, a characteristic qualified as masculine if it was judged to be
more desirable in American society for a man than for a woman, and it qualified
as feminine if it was judged to be more desirable for a woman than for a man.
